@@ -7,7 +7,7 @@ from collections.abc import Iterable
 from typing import get_type_hints
 from uuid import uuid4
 
-from sinai.exceptions import SourceNotFound
+from sinai.exceptions import SourceError, SourceNotFound
 from sinai.metrics import Metric
 from sinai.rules import Rule
 from sinai.sources import MetricSource
@@ -63,7 +63,7 @@ class Monitor:
     def __resolve_sources_from_init(self, rule_cls) -> None:
         self._source_map[rule_cls] = {}
         try:
-            annos = get_type_hints(rule_cls.__init__, include_extras=True)
+            annos = get_type_hints(rule_cls.__init__)
         except NameError:
             annos = rule_cls.__init__.__annotations__
         for arg, source_cls in annos.items():
@@ -86,7 +86,12 @@ class Monitor:
 
     def _connect_sources(self) -> None:
         for source_class in self.sources:
-            self._source_instances[source_class] = source_class(monitor=self)
+            try:
+                self._source_instances[source_class] = source_class(monitor=self)
+            except TypeError:
+                raise SourceError(
+                    f"The object {source_class} is not a valid Source class."
+                )
 
     def _connect_stores(self) -> None:
         for store_class in self.stores:
